import sublime, sublime_plugin
import urllib.parse
import urllib.request
import threading
import BBCodePreview.desktop

class BbcodePreviewCommand(sublime_plugin.TextCommand):
    def run(self, edit):
        text = self.view.substr( sublime.Region(0, self.view.size()) )

        thread = BbcodeApiCall(text, 5)
        thread.start()
        self.handle_thread(edit, thread)

    def handle_thread(self, edit, thread):
        if thread.is_alive():
            sublime.set_timeout(lambda: self.handle_thread(edit, thread), 100)
        else:
            BBCodePreview.desktop.open("https://fumbbl.com/FUMBBL.php?page=bbcode&id=" + thread.result)
        return

class BbcodeApiCall(threading.Thread):
    def __init__(self, string, timeout):
        self.original = string
        self.timeout = timeout
        self.result = None
        threading.Thread.__init__(self)
    def run(self):
        try:
            data = urllib.parse.urlencode({'bbcode': self.original})
            data = data.encode('utf-8')
            request = urllib.request.Request('https://fumbbl.com/FUMBBL.php?page=bbcode')
            request.add_header("User-Agent", "Sublime BBCode Preview")
            http_file = urllib.request.urlopen(request, data)
            self.result = http_file.read().decode('utf-8')
            return
        except (urllib.HTTPError) as e:
            err = '%s: HTTP error %s contacting API' % (__name__, str(e.code))
        except (urllib.URLError) as e:
            err = '%s: URL error %s contacting API' % (__name__, str(e.reason))
        sublime.error_message(err)
        self.result = False